@@ -87,7 +87,7 @@ void PythonHighlighter::highlightBlock(const QString &text)
     while (pos < text.length()) {
         // Trying to close current environments
         bool triggered = false;
-        for (int i = 0; i < flags.size() and not triggered; i++) {
+        for (int i = 0; i < flags.size() && !triggered; i++) {
             int flag = flags[i];
             QRegExp &regexp = regexps[i];
             QTextCharFormat &format = formats[i];
@@ -126,7 +126,7 @@ void PythonHighlighter::highlightBlock(const QString &text)
         singleLineCommentStart.indexIn(text, pos);
 
         if (singleLineCommentStartPos != -1
-            and singleLineCommentStartPos < minPos) {
+            && singleLineCommentStartPos < minPos) {
             setFormat(pos, text.length() - pos, commentFormat());
         break;
             } else if (minRegexp) {
@@ -143,7 +143,6 @@ void PythonHighlighter::highlightBlock(const QString &text)
 
 void PythonHighlighter::updateHighlight()
 {
-    qDebug();
 
     addVariables(PythonKeywords::instance()->variables());
     rehighlight();
